@@ -4,6 +4,8 @@ use strict;
 use File::Spec::Functions qw(catfile);
 use Array::Diff;
 
+our $VERSION = '0.87';
+
 sub order { 100 }
 
 ##################################################################
@@ -28,8 +30,11 @@ sub analyse {
         while (<$fh>) {
             chomp;
             next if /^\s*#/; # discard pure comments
-
-            s/\s.*$//; # strip file comments
+            if (s/^'(\\[\\']|.+)+'\s*.*/$1/) {
+                s/\\([\\'])/$1/g;
+            } else {
+                s/\s.*$//;
+            } # strip quotes and comments
             next unless $_; # discard blank lines
             push(@manifest,$_);
         }
@@ -77,7 +82,7 @@ q{Listening to: YAPC::Europe 2007};
 
 __END__
 
-=pod
+=encoding UTF-8
 
 =head1 NAME
 
@@ -121,9 +126,7 @@ Thomas Klausner, <domm@cpan.org>, http://domm.plix.at
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2003-2006, 2009  Thomas Klausner
+Copyright © 2003–2006, 2009 L<Thomas Klausner|https://metacpan.org/author/domm>
 
 You may use and distribute this module according to the same terms
 that Perl is distributed under.
-
-=cut
